xxf_lifecycle library

Classes

ChildPageLifecycleWrapper
Lifecycle wrapper for children of PageView and TabBarView.
LifecycleObserver
LifecycleWrapper
Lifecycle wrapper for Widget. If you are using a StatefulWidget, consider mixin it with LifecycleMixin.
PageViewLifecycleWrapper
Lifecycle wrapper for PageView / TabBarView.
PageViewLifecycleWrapperState
ScrollViewItemLifecycleWrapper
Wrapper widget for item of scrollable widget.

Mixins

ChildPageSubscribeLifecycleMixin<T extends StatefulWidget>
Subscribe lifecycle event from PageViewDispatchLifecycleMixin. This is used in child page of PageView.
LifecycleAware
A mixin for widgets that are aware of their current lifecycle.
LifecycleMixin<T extends StatefulWidget>
Subscribes lifecycle events for normal widgets.
ScrollViewItemSubscribeLifecycleMixin<T extends StatefulWidget>
Used for child widget of a ScrollView. See ListView/GridView/CustomScrollView.
WidgetDispatchLifecycleMixin<T extends StatefulWidget>
Widget that needs to dispatch lifecycle to it's children should mixin this.

Extensions

LifecycleObserverExtensions on LifecycleObserver
路由栈工具

Properties

defaultLifecycleObserver LifecycleObserver
An observer can only be used by one Navigator (include MaterialApp). If you have your own Navigator, please use a new instance of LifecycleObserver.
final
rootRoute Route?
根Route
no setter
rootStack List<Route>
堆栈
no setter
routeStack List<Route>
堆栈
no setter
topRoute Route?
栈顶route
no setter

Typedefs

OnLifecycleEvent = void Function(LifecycleEvent event)