LifecycleObserver class
- Inheritance
-
- Object
- NavigatorObserver
- LifecycleObserver
- Mixed-in types
- Available extensions
Constructors
- LifecycleObserver()
-
Avoids calling this constructor in
buildmethod. Call dispose when it will never be used, e.g. call it in State#dispose. - LifecycleObserver.internalGet(BuildContext context)
-
Only for internal usage.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
The navigator that the observer is observing, if any.
no setterinherited
- rootRoute → Route?
-
Available on LifecycleObserver, provided by the LifecycleObserverExtensions extension
根Routeno setter -
rootStack
→ List<
Route> -
Available on LifecycleObserver, provided by the LifecycleObserverExtensions extension
堆栈no setter -
routeStack
→ List<
Route> -
Available on LifecycleObserver, provided by the LifecycleObserverExtensions extension
堆栈no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topRoute → Route?
-
Available on LifecycleObserver, provided by the LifecycleObserverExtensions extension
栈顶routeno setter
Methods
-
didChangeAccessibilityFeatures(
) → void -
Called when the system changes the set of currently active accessibility
features.
inherited
-
didChangeAppLifecycleState(
AppLifecycleState state) → void -
Called when the system puts the app in the background or returns
the app to the foreground.
override
-
didChangeLocales(
List< Locale> ? locales) → void -
Called when the system tells the app that the user's locale has
changed. For example, if the user changes the system language
settings.
inherited
-
didChangeMetrics(
) → void -
Called when the application's dimensions change. For example,
when a phone is rotated.
inherited
-
didChangePlatformBrightness(
) → void -
Called when the platform brightness changes.
inherited
-
didChangeTextScaleFactor(
) → void -
Called when the platform's text scale factor changes.
inherited
-
didChangeTop(
Route topRoute, Route? previousTopRoute) → void -
The top most route has changed.
inherited
-
didChangeViewFocus(
ViewFocusEvent event) → void -
Called whenever the PlatformDispatcher receives a notification that the
focus state on a view has changed.
inherited
-
didHaveMemoryPressure(
) → void -
Called when the system is running low on memory.
inherited
-
didPop(
Route route, Route? previousRoute) → void -
The Navigator popped
route.override -
didPopRoute(
) → Future< bool> -
Called when the system tells the app to pop the current route, such as
after a system back button press or back gesture.
inherited
-
didPush(
Route route, Route? previousRoute) → void -
When boot first page,
previousRouteis null.override -
didPushRoute(
String route) → Future< bool> -
Called when the host tells the application to push a new route onto the
navigator.
inherited
-
didPushRouteInformation(
RouteInformation routeInformation) → Future< bool> -
Called when the host tells the application to push a new
RouteInformation and a restoration state onto the router.
inherited
-
didRemove(
Route route, Route? previousRoute) → void -
routeRoute that will be removed.previousRouteA route below the removed route. When removing multiple routes, thepreviousRouteis unchanged, and may be null.override -
didReplace(
{Route? newRoute, Route? oldRoute}) → void -
The Navigator replaced
oldRoutewithnewRoute.override -
didRequestAppExit(
) → Future< AppExitResponse> -
Called when a request is received from the system to exit the application.
inherited
-
didStartUserGesture(
Route route, Route? previousRoute) → void -
The Navigator's routes are being moved by a user gesture.
inherited
-
didStopUserGesture(
) → void -
User gesture is no longer controlling the Navigator.
inherited
-
dispose(
) → void - Must be called when the observer will no longer be used.
-
findRoute(
String routeName) → Route? -
Finds route by
routeName. -
handleCancelBackGesture(
) → void -
Called when a predictive back gesture is canceled, indicating that no
navigation should occur.
inherited
-
handleCommitBackGesture(
) → void -
Called when a predictive back gesture is finished successfully, indicating
that the current route should be popped.
inherited
-
handleStartBackGesture(
PredictiveBackEvent backEvent) → bool -
Called at the start of a predictive back gesture.
inherited
-
handleStatusBarTap(
) → void -
Called when the user taps the status bar on iOS, to scroll a scroll
view to the top.
inherited
-
handleUpdateBackGestureProgress(
PredictiveBackEvent backEvent) → void -
Called when a predictive back gesture moves.
inherited
-
iterateRoutes(
bool callback(Route route)) → void -
Iterates routes. It's usually used for locating a specific route.
callbackThe callback function to be called for each route. Returns true to break the iteration. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeNamed<
T> (String routeName, [T? result]) → void -
Remove a route according to the
routeName. -
removeRoute<
T> (Route route, [T? result]) → void - Removes a route.
-
subscribe(
LifecycleAware lifecycleAware, Route route) → void -
lifecycleAwaresubscribes events. -
toString(
) → String -
A string representation of this object.
inherited
-
unsubscribe(
LifecycleAware lifecycleAware) → void -
lifecycleAwareunsubscribes events.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited